==> R14.1.1-noncore.tar: tqscintilla-trinity-14.1.1/tqt/tqextscintillalexerlua.h <==
// This defines the interface to the TQextScintillaLexerLua class.
//
// Copyright (c) 2006
// 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
// 
// This file is part of TQScintilla.
// 
// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
// details.
// 
// You should have received a copy of the GNU General Public License along with
// TQScintilla; see the file LICENSE.  If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


#ifndef TQEXTSCINTILLALEXERLUA_H
#define TQEXTSCINTILLALEXERLUA_H


#include <tqobject.h>

#include <tqextscintillaglobal.h>
#include <tqextscintillalexer.h>


//! \brief The TQextScintillaLexerLua class encapsulates the Scintilla Lua
//! lexer.
class TQEXTSCINTILLA_EXPORT TQextScintillaLexerLua : public TQextScintillaLexer
{
	TQ_OBJECT
  

public:
	//! This enum defines the meanings of the different styles used by the
	//! Lua lexer.
	enum {
		//! The default.
		Default = 0,

		//! A block comment.
		Comment = 1,

		//! A line comment.
		LineComment = 2,

		//! A number.
		Number = 4,

		//! A keyword.
		Keyword = 5,

		//! A string.
		String = 6,

		//! A character.
		Character = 7,

		//! A literal string.
		LiteralString = 8,

		//! Preprocessor
		Preprocessor = 9,

		//! An operator.
		Operator = 10,

		//! An identifier
		Identifier = 11,

		//! The end of a line where a string is not closed.
		UnclosedString = 12,

		//! Basic functions.
		BasicFunctions = 13,

		//! String, table and maths functions.
		StringTableMathsFunctions = 14,

		//! Coroutines, I/O and system facilities.
		CoroutinesIOSystemFacilities = 15
	};

	//! Construct a TQextScintillaLexerLua with parent \a parent and name
	//! \a name.  \a parent is typically the TQextScintilla instance.
	TQextScintillaLexerLua(TQObject *parent = 0,const char *name = 0);

	//! Destroys the TQextScintillaLexerLua instance.
	virtual ~TQextScintillaLexerLua();

	//! Returns the name of the language.
	const char *language() const;

	//! Returns the name of the lexer.  Some lexers support a number of
	//! languages.
	const char *lexer() const;

	//! \internal Returns a space separated list of words or characters in
	//! a particular style that define the start of a block for
	//! auto-indentation.  The styles is returned via \a style.
	const char *blockStart(int *style = 0) const;

	//! \internal Returns the style used for braces for brace matching.
	int braceStyle() const;

	//! Returns the foreground colour of the text for style number
	//! \a style.
	//!
	//! \sa paper()
	TQColor color(int style) const;

	//! Returns the end-of-line fill for style number \a style.
	bool eolFill(int style) const;

	//! Returns the font for style number \a style.
	TQFont font(int style) const;

	//! Returns the set of keywords for the keyword set \a set recognised
	//! by the lexer as a space separated string.
	const char *keywords(int set) const;

	//! Returns the descriptive name for style number \a style.  If the
	//! style is invalid for this language then TQString() is returned.
	//! This is intended to be used in user preference dialogs.
	TQString description(int style) const;

	//! Returns the background colour of the text for style number
	//! \a style.
	//!
	//! \sa color()
	TQColor paper(int style) const;

	//! Causes all properties to be refreshed by emitting the
	//! propertyChanged() signal as required.
	void refreshProperties();

	//! Returns TRUE if trailing blank lines are included in a fold block.
	//!
	//! \sa setFoldCompact()
	bool foldCompact() const;

public slots:
	//! If \a fold is TRUE then trailing blank lines are included in a fold
	//! block. The default is TRUE.
	//!
	//! \sa foldCompact()
	virtual void setFoldCompact(bool fold);

protected:
	//! The lexer's properties are read from the settings \a qs.  \a prefix
	//! (which has a trailing '/') should be used as a prefix to the key of
	//! each setting.  TRUE is returned if there is no error.
	//!
	bool readProperties(TQSettings &qs,const TQString &prefix);

	//! The lexer's properties are written to the settings \a qs.
	//! \a prefix (which has a trailing '/') should be used as a prefix to
	//! the key of each setting.  TRUE is returned if there is no error.
	//!
	bool writeProperties(TQSettings &qs,const TQString &prefix) const;

private:
	void setCompactProp();

	bool fold_compact;

#if defined(TQ_DISABLE_COPY)
	TQextScintillaLexerLua(const TQextScintillaLexerLua &);
	TQextScintillaLexerLua &operator=(const TQextScintillaLexerLua &);
#endif
};

#endif

==> R14.1.4-noncore.tar: tqscintilla-trinity-14.1.4/tqt/tqextscintillalexerlua.h <==
// This defines the interface to the TQextScintillaLexerLua class.
//
// Copyright (c) 2006
// 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
// 
// This file is part of TQScintilla.
// 
// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
// details.
// 
// You should have received a copy of the GNU General Public License along with
// TQScintilla; see the file LICENSE.  If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


#ifndef TQEXTSCINTILLALEXERLUA_H
#define TQEXTSCINTILLALEXERLUA_H


#include <tqobject.h>

#include <tqextscintillaglobal.h>
#include <tqextscintillalexer.h>


//! \brief The TQextScintillaLexerLua class encapsulates the Scintilla Lua
//! lexer.
class TQEXTSCINTILLA_EXPORT TQextScintillaLexerLua : public TQextScintillaLexer
{
	TQ_OBJECT
  

public:
	//! This enum defines the meanings of the different styles used by the
	//! Lua lexer.
	enum {
		//! The default.
		Default = 0,

		//! A block comment.
		Comment = 1,

		//! A line comment.
		LineComment = 2,

		//! A number.
		Number = 4,

		//! A keyword.
		Keyword = 5,

		//! A string.
		String = 6,

		//! A character.
		Character = 7,

		//! A literal string.
		LiteralString = 8,

		//! Preprocessor
		Preprocessor = 9,

		//! An operator.
		Operator = 10,

		//! An identifier
		Identifier = 11,

		//! The end of a line where a string is not closed.
		UnclosedString = 12,

		//! Basic functions.
		BasicFunctions = 13,

		//! String, table and maths functions.
		StringTableMathsFunctions = 14,

		//! Coroutines, I/O and system facilities.
		CoroutinesIOSystemFacilities = 15
	};

	//! Construct a TQextScintillaLexerLua with parent \a parent and name
	//! \a name.  \a parent is typically the TQextScintilla instance.
	TQextScintillaLexerLua(TQObject *parent = 0,const char *name = 0);

	//! Destroys the TQextScintillaLexerLua instance.
	virtual ~TQextScintillaLexerLua();

	//! Returns the name of the language.
	const char *language() const;

	//! Returns the name of the lexer.  Some lexers support a number of
	//! languages.
	const char *lexer() const;

	//! \internal Returns a space separated list of words or characters in
	//! a particular style that define the start of a block for
	//! auto-indentation.  The styles is returned via \a style.
	const char *blockStart(int *style = 0) const;

	//! \internal Returns the style used for braces for brace matching.
	int braceStyle() const;

	//! Returns the foreground colour of the text for style number
	//! \a style.
	//!
	//! \sa paper()
	TQColor color(int style) const;

	//! Returns the end-of-line fill for style number \a style.
	bool eolFill(int style) const;

	//! Returns the font for style number \a style.
	TQFont font(int style) const;

	//! Returns the set of keywords for the keyword set \a set recognised
	//! by the lexer as a space separated string.
	const char *keywords(int set) const;

	//! Returns the descriptive name for style number \a style.  If the
	//! style is invalid for this language then TQString() is returned.
	//! This is intended to be used in user preference dialogs.
	TQString description(int style) const;

	//! Returns the background colour of the text for style number
	//! \a style.
	//!
	//! \sa color()
	TQColor paper(int style) const;

	//! Causes all properties to be refreshed by emitting the
	//! propertyChanged() signal as required.
	void refreshProperties();

	//! Returns true if trailing blank lines are included in a fold block.
	//!
	//! \sa setFoldCompact()
	bool foldCompact() const;

public slots:
	//! If \a fold is true then trailing blank lines are included in a fold
	//! block. The default is true.
	//!
	//! \sa foldCompact()
	virtual void setFoldCompact(bool fold);

protected:
	//! The lexer's properties are read from the settings \a qs.  \a prefix
	//! (which has a trailing '/') should be used as a prefix to the key of
	//! each setting.  true is returned if there is no error.
	//!
	bool readProperties(TQSettings &qs,const TQString &prefix);

	//! The lexer's properties are written to the settings \a qs.
	//! \a prefix (which has a trailing '/') should be used as a prefix to
	//! the key of each setting.  true is returned if there is no error.
	//!
	bool writeProperties(TQSettings &qs,const TQString &prefix) const;

private:
	void setCompactProp();

	bool fold_compact;

#if defined(TQ_DISABLE_COPY)
	TQextScintillaLexerLua(const TQextScintillaLexerLua &);
	TQextScintillaLexerLua &operator=(const TQextScintillaLexerLua &);
#endif
};

#endif
